/* acconfig.h
 * #ifdefs to be controlled by "configure"
 *
 * $Id: acconfig.h,v 1.21 2001/12/12 05:26:53 gerald Exp $
 *
 * Ethereal - Network traffic analyzer
 * By Gerald Combs <gerald@ethereal.org>
 * Copyright 1998 Gerald Combs
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#undef PACKAGE

#undef VERSION

#undef HAVE_PLUGINS

#undef HAVE_SA_LEN

#undef DATAFILE_DIR

#undef NEED_SNPRINTF_H

#undef NEED_STRERROR_H

#undef NEED_STRPTIME_H

#undef HAVE_LIBPCAP

#undef HAVE_PCAP_VERSION

#undef PLUGIN_DIR

#undef RED_HAT_MODIFIED_UCD_SNMP
